@@ -41,7 +41,8 @@ Selector::Selector(Lum::Model::SizeT *seconds)
    addAction(new Lum::Model::Action()),
    editAction(new Lum::Model::Action()),
    removeAction(new Lum::Model::Action()),
-   okAction(new Lum::Model::Action())
+   okAction(new Lum::Model::Action()),
+   success(false)
 {
   seconds->Push();
 
@@ -76,13 +77,13 @@ Lum::Object* Selector::GetContent()
   horiz=Lum::HPanel::Create(true,true);
 
   headerModel=new Lum::Model::HeaderImpl();
-  headerModel->AddColumn(_(L"TBL_TEA_HEADER_TEA",L"Tea"),Lum::Base::Size::stdCharWidth,25,true);
+  headerModel->AddColumn(_(L"TBL_TEA_HEADER_TEA",L"Tea"),Lum::Base::Size::stdCharWidth,30,true);
 
   table=new Lum::Table();
   table->SetFlex(true,true);
   table->SetShowHeader(false);
-  table->GetTableView()->SetAutoFitColumns(true);
-  table->GetTableView()->SetAutoVSize(true);
+  //table->GetTableView()->SetAutoFitColumns(true);
+  table->GetTableView()->SetAutoHSize(true);
   table->SetModel(list);
   table->SetHeaderModel(headerModel);
   table->SetSelection(selection);
@@ -194,6 +195,7 @@ void Selector::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
     configurationChanged=true;
   }
   else if (model==okAction && okAction->IsFinished()) {
+    success=true;
     seconds->Save();
     Exit();
   }
@@ -201,3 +203,8 @@ void Selector::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
   Lum::Dlg::ActionDialog::Resync(model,msg);
 }
 
+bool Selector::Success() const
+{
+  return success;
+}
+
