@@ -2,8 +2,8 @@
 #define STOPWATCH_H
 
 /*
-  Kandis - A tea steepming timer.
-  Copyright (C) 2007  Tim Teulings
+  TimerJinni - A general timing application
+  Copyright (C) 2009  Tim Teulings
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,6 +37,10 @@ private:
   Lum::OS::ColorRef     alarmColor;
   bool                  alarm;
   bool                  showInvert;
+  size_t                minDigitWidth;
+  size_t                minDivWidth;
+  size_t                digitWidth;
+  size_t                divWidth;
 
 public:
   StopWatch();
@@ -48,7 +52,7 @@ public:
 
   void CalcSize();
 
-  Lum::OS::Font* FindFont();
+  Lum::OS::Font* FindFont(size_t& digitWidth, size_t& divWidth);
 
   void Layout();
   void Draw(int x, int y, size_t w, size_t h);
